<template>
	<header class="bg-white shadow-sm flex items-center">
		<div class="flex w-full">
			<div class="flex items-center h-20 mx-auto">
				<!-- Logo -->
				<div class="flex items-center cursor-pointer">
					<router-link to="/">
						<img :src="headerLogo" alt="Logo" class="h-20 w-auto" />
					</router-link>
					<!-- <span class="text-extra-large font-bold">工业大数据平台</span> -->
				</div>

				<!-- Navigation Menu -->
				<nav class="flex ml-8">
					<el-menu mode="horizontal" :ellipsis="false" class="border-none" router :default-active="activeRoute">
						<el-menu-item index="/home" class="!px-4">首页</el-menu-item>
						<el-menu-item index="/certified-products" class="!px-4">认证产品</el-menu-item>
						<el-menu-item index="/eec-label-search" class="!px-4">证书查询</el-menu-item>
						<el-menu-item index="/news-detail/99" class="!px-4">补贴政策</el-menu-item>
						<el-menu-item class="!px-4" @click="linkClick('http://xpump.net/#/Index')">查泵网</el-menu-item>
					</el-menu>
				</nav>

				<!-- Search and User Actions -->
				<div class="flex items-center space-x-8 ml-[65px]">
					<el-input v-model="searchQuery" placeholder="找工业/找大数据" class="w-48">
						<template #suffix>
							<el-icon><Search /></el-icon>
						</template>
					</el-input>

					<div class="flex items-center text-gray-600 text-sm text-nowrap">
						<template v-if="!userInfo">
							<a href="#" class="hover:text-blue-500">注册</a>
							<span class="mx-2">·</span>
							<router-link to="/login" class="hover:text-blue-500">登录</router-link>
						</template>
						<template v-else>
							<span class="text-blue-500 mr-2">{{ userInfo.username }}</span>
							<a href="#" class="hover:text-blue-500" @click.prevent="handleLogout">退出</a>
						</template>
					</div>
				</div>
			</div>
		</div>
	</header>
</template>

<script setup lang="ts">
import headerLogo from '@/assets/logo/header_logo.png';
import { Search } from '@element-plus/icons-vue';
import { ElMessage } from 'element-plus';
import { computed, ref } from 'vue';
import { useRoute, useRouter } from 'vue-router';

const route = useRoute();
const router = useRouter();
const searchQuery = ref('');

const activeRoute = computed(() => route.path);

// 获取用户信息
const userInfo = computed(() => {
	const info = localStorage.getItem('userInfo');
	return info ? JSON.parse(info) : null;
});

// 处理登出
const handleLogout = () => {
	localStorage.removeItem('userInfo');
	ElMessage.success('已退出登录');
	router.push('/login');
};

const linkClick = (url) => {
	window.open(url, '_blank');
};
</script>

<style scoped>
:deep(.el-menu--horizontal .el-menu-item) {
	height: 64px;
	line-height: 64px;
	font-size: 14px;
}

:deep(.el-menu--horizontal) {
	border-bottom: none;
}
</style>
